@@ -1,16 +1,12 @@
 import asyncio
-
-import pytest
+from typing import Callable
 
 from async_lru import alru_cache
 
 
-pytestmark = pytest.mark.asyncio
-
-
-async def test_cache_clear(check_lru, loop):
+async def test_cache_clear(check_lru: Callable[..., None]) -> None:
     @alru_cache()
-    async def coro(val):
+    async def coro(val: int) -> int:
         return val
 
     inputs = [1, 2, 3]
